
#include <Arduino.h>
#include "DDS_tracking.h"
#include "AD9851.h"


// This is a simple test programme that may be compiled to run on an Arduino Nano, Duo or Mega2560,
// and control an AD9850 or AD9851 DDS module. When run, the selected DDS will output a frequency of 1MHZ.
//
// Before compiling, make sure you have uncommented the correct defines for your Arduino board
// and DDS type in DDS_tracking.h
//
// These are the default pins used for each type of Arduino board - they may be changed
// in the setup() function.
//
// Variable		DDS pin		Mega	Uno		Nano
// 
// reset		RESET		23		10		10
// data			D7			25		11		11
// update		FQ_UD		27		 9		 9
// clock		W_CLK		31		13		13
//
// Setting the continuousSet flag to true will cause the frequency to be repeatedly set 
// with a 100ms pause between each set sequence. This may be usefull if you need to probe 
// around with an oscilloscope. Default is set to false for a single frequency set
//
// Steve Andrew - Aug 2018

// set to true for continuous frequency sets
bool continuousSetFlag = false;

byte resetPin;
byte dataPin;
byte updatePin;
byte clockPin;

DDS dds;
bool setSpotFlag;
String ddsType = "No DDS set";


void setup(void)
{
	Serial.begin(115200);

	Serial.println("AD9850 and AD9851 Test programme");
	Serial.println("Starting setup...");

#ifdef Arduino_Nano
	updatePin = 9;
	resetPin = 10;
	dataPin = 11;
	clockPin = 13;
	Serial.println("Pins set for Nano");
#endif

#ifdef Arduino_UNO
	updatePin = 9;
	resetPin = 10;
	dataPin = 11;
	clockPin = 13;
	Serial.println("Pins set for Uno");
#endif

#ifdef Mega2560
	updatePin = 27;
	resetPin = 23;
	dataPin = 25;
	clockPin = 31;
	Serial.println("Pins set for Mega2560");
#endif

 #ifdef AD9851
	dds.enableMultiplier = true;
	dds.clockFrequency = 180000000.0;
	ddsType = "DDS is AD9851";
 #endif
     
 #ifdef AD9850
	dds.enableMultiplier = false;
	dds.clockFrequency = 125000000.0;
	ddsType = "DDS is AD9850";
 #endif	

	setDDSpins();

	Serial.println(ddsType);
	
	// should not be needed, but allows everything to settle down
	delay(100);

	dds.reset();
	dds.sendFrequency(dds.frequency);
	dds.updateFrequency();

	Serial.println("DDS frequency is 1MHz");

	// this will be cleared once the frequency has been set, unless continuousSetFlag has been set to true
	setSpotFlag = true;

	if(continuousSetFlag)
		Serial.println("DDS continous frequency update is: ON");
	else
		Serial.println("DDS continous frequency update is: OFF");

	sei();

	Serial.println("Setup complete");
}

void loop(void)
{
	// sets the DDS output frequency to 1MHZ. 
	// frequency will be set continuously if continuousSetFlag is true
	
	if (setSpotFlag)
	{
		dds.frequency = 1000000.0;
		dds.sendFrequency(dds.frequency);
		dds.updateFrequency();
	}

	if (continuousSetFlag)
		delay(100);
	else
		setSpotFlag = false;
}

void setDDSpins()
{
	dds.resetPin = resetPin;
	dds.dataPin = dataPin;
	dds.updatePin = updatePin;
	dds.clkPin = clockPin;

	pinMode(dds.resetPin, OUTPUT);
	pinMode(dds.dataPin, OUTPUT);
	pinMode(dds.updatePin, OUTPUT);
	pinMode(dds.clkPin, OUTPUT);
}


